package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcIdcdw;
import com.ruoyi.tcZz.domain.TcJbmap;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcJbmapService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 举报地图Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "举报地图")
@RequestMapping("/tcZz/netManage/jbmap")
public class TcJbmapController extends BaseController {
    @Autowired
    private ITcJbmapService tcJbmapService;

    /**
     * 查询举报地图列表
     */
    @ApiOperation(value = "查询举报地图列表", response = TcJbmap.class)
    @GetMapping("/list")
    public TableDataInfo list(TcJbmap tcJbmap) {
        startPage();
        List<TcJbmap> list = tcJbmapService.selectTcJbmapList(tcJbmap);
        return getDataTable(list);
    }

    /**
     * 导出举报地图列表
     */
    @ApiOperation(value = "导出举报地图列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcJbmap tcJbmap) {
        List<TcJbmap> list = tcJbmapService.selectTcJbmapList(tcJbmap);
        ExcelUtil<TcJbmap> util = new ExcelUtil<TcJbmap>(TcJbmap.class);
        util.exportExcel(response, list, "举报地图数据");
    }

    /**
     * 获取举报地图详细信息
     */
    @ApiOperation(value = "获取举报地图详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcJbmapService.selectTcJbmapById(id));
    }

    /**
     * 新增举报地图
     */
    @ApiOperation(value = "新增举报地图")
    @PostMapping
    public AjaxResult add(@RequestBody TcJbmap tcJbmap) {
        return toAjax(tcJbmapService.insertTcJbmap(tcJbmap));
    }

    /**
     * 修改举报地图
     */
    @ApiOperation(value = "修改举报地图")
    @PutMapping
    public AjaxResult edit(@RequestBody TcJbmap tcJbmap) {
        return toAjax(tcJbmapService.updateTcJbmap(tcJbmap));
    }

    /**
     * 删除举报地图
     */
    @ApiOperation(value = "删除举报地图")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcJbmapService.deleteTcJbmapByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcJbmap> util = new ExcelUtil<TcJbmap>(TcJbmap.class);
        List<TcJbmap> tcJbmapList = util.importExcel(file.getInputStream());
        tcJbmapService.importUser(tcJbmapList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcJbmapService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcJbmap> util = new ExcelUtil<TcJbmap>(TcJbmap.class);
        util.importTemplateExcel(response, " 举报地图");
    }
}
